@@ -322,6 +322,30 @@ class sqlobj(object):
 	def __setitem__(self, key, value):
 		self.add_frame(key, value)
 
+	def drop_table(self, table_name, backup=True):
+		just_enter = False
+		if self.exists is None:
+			just_enter = True
+			self.just_enter()
+
+		if table_name in self.table_names():
+			if backup:
+				self[table_name].to_csv(".backup_{0}.csv".format(table_name))
+
+			if just_enter:
+				current_cursor = self.connection.cursor()
+				current_cursor.execute("DROP table IF EXISTS {0};".format({0}))
+				current_cursor = None
+			else:
+				try:
+					self.dataframes.pop(table_name)
+				except: pass
+
+		if just_enter:
+			self.exit()
+
+		return
+
 	def to_xcylobj(self):
 		output = xcylobj("temp.xlsx")
 		for key, value in self.dataframes.items():
